@@ -38,7 +38,7 @@ import org.w3c.dom.events.EventTarget;
  * creating new DOM classes that inherit from these elements.
  *
  * @author <a href="mailto:cam%40mcc%2eid%2eau">Cameron McCormack</a>
- * @version $Id: TimedElement.java 1808021 2017-09-11 12:17:28Z ssteiner $
+ * @version $Id: TimedElement.java 1831630 2018-05-15 12:56:55Z ssteiner $
  */
 public abstract class TimedElement implements SMILConstants {
 
@@ -1403,7 +1403,7 @@ public abstract class TimedElement implements SMILConstants {
      * exposing animation information from the document.
      */
     public TimingSpecifier[] getBeginTimingSpecifiers() {
-        return (TimingSpecifier[]) beginTimes.clone();
+        return beginTimes.clone();
     }
 
     /**
@@ -1413,7 +1413,7 @@ public abstract class TimedElement implements SMILConstants {
      * exposing animation information from the document.
      */
     public TimingSpecifier[] getEndTimingSpecifiers() {
-        return (TimingSpecifier[]) endTimes.clone();
+        return endTimes.clone();
     }
 
     /**
