@@ -21,7 +21,7 @@ package org.apache.batik.dom;
 import java.io.Serializable;
 
 import org.apache.batik.dom.events.DOMMutationEvent;
-import org.apache.batik.util.XMLConstants;
+import org.apache.batik.constants.XMLConstants;
 
 import org.w3c.dom.DOMException;
 import org.w3c.dom.Node;
@@ -32,7 +32,7 @@ import org.w3c.dom.events.MutationEvent;
  * This class implements the Node interface with support for children.
  *
  * @author <a href="mailto:stephane@hillion.org">Stephane Hillion</a>
- * @version $Id: AbstractParentNode.java 1802297 2017-07-18 13:58:12Z ssteiner $
+ * @version $Id: AbstractParentNode.java 1851346 2019-01-15 13:41:00Z ssteiner $
  */
 public abstract class AbstractParentNode extends AbstractNode {
 
