@@ -18,6 +18,7 @@
  */
 package org.apache.batik.swing.gvt;
 
+import java.awt.AWTPermission;
 import java.awt.AlphaComposite;
 import java.awt.Color;
 import java.awt.Dimension;
@@ -67,7 +68,7 @@ import org.apache.batik.util.Platform;
  * This class represents a component which can display a GVT tree.
  *
  * @author <a href="mailto:stephane@hillion.org">Stephane Hillion</a>
- * @version $Id: JGVTComponent.java 1808021 2017-09-11 12:17:28Z ssteiner $
+ * @version $Id: JGVTComponent.java 1839938 2018-09-03 11:22:05Z ssteiner $
  */
 public class JGVTComponent extends JComponent {
 
@@ -1078,7 +1079,7 @@ public class JGVTComponent extends JComponent {
                         (e.getComponent(),
                          MouseEvent.MOUSE_CLICKED,
                          e.getWhen(),
-                         e.getModifiers(),
+                         e.getModifiersEx(),
                          e.getX(),
                          e.getY(),
                          e.getClickCount(),
@@ -1272,7 +1273,7 @@ public class JGVTComponent extends JComponent {
             securityManager = System.getSecurityManager();
             if (securityManager != null) {
                 try {
-                    securityManager.checkPermission(new java.awt.AWTPermission("accessClipboard"));
+                    securityManager.checkPermission(new AWTPermission("accessClipboard"));
                 } catch (SecurityException e) {
                     return; // Can't access clipboard.
                 }
